************
Data Methods
************

.. automodule:: gouda
  :members: arr_sample, factors, flip_dict, num_digits, prime_factors, prime_overlap, rescale, sigmoid, softmax, normalize, roc_curve, mcc_curve, optimal_mcc_from_roc, spec_at_sens, get_confusion_stats, dice_coef, jaccard_coef, value_crossing
  :noindex: ensure_dir, next_filename, load_json, save_json, is_image, basicname, get_sorted_filenames
